@@ -1,6 +1,9 @@
 from .bases import Pys
 from .constants import DEFAULT
+from .utils.decorators import immutable
+from .utils.general import setimuattr
 
+@immutable
 class PysContext(Pys):
 
     __slots__ = ('file', 'name', 'qualname', 'flags', 'symbol_table', 'parent', 'parent_entry_position')
@@ -18,16 +21,16 @@ class PysContext(Pys):
         if flags is None and parent:
             flags = parent.flags
 
-        self.file = file
-        self.name = name
-        self.qualname = qualname
-        self.flags = DEFAULT if flags is None else flags
-        self.symbol_table = symbol_table
-        self.parent = parent
-        self.parent_entry_position = parent_entry_position
+        setimuattr(self, 'file', file)
+        setimuattr(self, 'name', name)
+        setimuattr(self, 'qualname', qualname)
+        setimuattr(self, 'flags', DEFAULT if flags is None else flags)
+        setimuattr(self, 'symbol_table', symbol_table)
+        setimuattr(self, 'parent', parent)
+        setimuattr(self, 'parent_entry_position', parent_entry_position)
 
     def __repr__(self):
-        return '<Context {!r}>'.format(self.name)
+        return f'<Context {self.name!r}>'
 
 class PysClassContext(PysContext):
 
@@ -40,10 +43,11 @@ class PysClassContext(PysContext):
         parent,
         parent_entry_position
     ):
+        qualname = parent.qualname
         super().__init__(
             file=parent.file,
             name=name,
-            qualname=('' if parent.qualname is None else parent.qualname + '.') + name,
+            qualname=('' if qualname is None else qualname + '.') + name,
             symbol_table=symbol_table,
             parent=parent,
             parent_entry_position=parent_entry_position
